/**
 * data_pronouncer.h
 * =================
 * Interface to basic pronouncer functionality based on DATA Interactive.
 *
 * By Hkan L. Younes (lorens@acm.org)
 */

#ifndef DTE_PRONOUNCER_H
#define DTE_PRONOUNCER_H

#define MAX_PATHLEN 32

/**
 * Initialize pronouncer.
 *
 * Returns -1 on failure, and 0 on success.
 *
 * N.B. must be called before the pronouncer is used.
 */
extern int initializePronouncer();

/**
 * Finalizes pronouncer.
 */
extern void finalizePronouncer();

/**
 * Loads a model to work with.
 *
 * Parameters:
 *  path  - path to file containing the model.
 *
 * Returns -1 on failure, and 0 on success.
 */
extern int loadModel(char* path);

/**
 * Sets values of variables in the model.
 *
 * Parameters:
 *  node_path - path to node.
 *  path_len  - length of node path.
 *  values    - new values for variables.
 *  nvaluea   - number of variables to set.
 */
extern void setModelValues(const int* node_path, int path_len,
                       const double* values, int nvalues);

/**
 * Gets an advice.
 *
 * Parameters:
 *  decision_path - path to decision node, or NULL for root node.
 *  path_len      - length of node path.
 *
 * Returns the index of the action that maximizes the expected utility.
 */
extern int evaluateModel(const int *decision_path, int path_len);

#endif /* DTE_PRONOUNCER */
